"""deepmanager.command.check

Implements DeepManager's 'check' command."""

from types import IntType
from deepmanager.core import Command
from deepmanager.errors import *
from deepmanager.package import *

class check(Command):

	description = "check relations between packages"

	user_options = [
		('rpm-db', None,
		 "use local installed database as information source"),
		('rpm-hdlist=', None,
		 "use given hdlists as information sources"),
		('broken', None,
		 "check broken require relations"),
		]
	
	boolean_options = ["broken"]
	
	list_options = ["rpm_hdlist"]

	def initialize_options(self):
		self.rpm_db = 0
		self.rpm_hdlist = []
		self.broken = 0
	
	def finalize_options(self):
		if not (self.rpm_db or self.rpm_hdlist):
			raise DeepManagerOptionError, \
				  "you must specify one or more information sources"

		self.ensure_filename_list("rpm_hdlist")

	def run(self):
		if self.rpm_db:
			pm = get_pm("rpm")
			self.announce("reading database...", noeol=1)
			self.pkgset = pm.pkgset_from_db()
			self.announce("done")

		if self.rpm_hdlist:
			pm = get_pm("rpm")
			self.announce("reading hdlists...", noeol=1)
			self.pkgset = pm.pkgset_from_hdlists(self.rpm_hdlist)
			self.announce("done")

		self.announce("resolving dependencies...", noeol=1)
		self.pkgset.resolve()
		self.announce("done")
		
		if self.broken:
			self.check_broken()

		self.announce("finished!")
	
	def check_broken(self):
		for pkg in self.pkgset:
			for rel in pkg.requires:
				if not rel.relations:
					print "%s requires %s" % (pkg, rel)
					avail = self.pkgset.who_provides_any(rel.name)
					if avail:
						for i in range(len(avail)):
							if avail[i].package.name != avail[i].name:
								avail[i] = "%s (by %s)" % \
									(str(avail[i]), str(avail[i].package))
							else:
								avail[i] = str(avail[i])
						print "available:", ", ".join(avail)
	
# vim:nowrap:sw=4:ts=4
